==> tomee-project-8.0.12-source-release.zip: tomee-project-8.0.12/server/openejb-http/src/main/java/org/apache/openejb/server/httpd/ServletByteArrayIntputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
    * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.server.httpd;

import javax.servlet.ReadListener;
import javax.servlet.ServletInputStream;
import java.io.ByteArrayInputStream;
import java.io.IOException;

public class ServletByteArrayIntputStream extends ServletInputStream {
    private final ByteArrayInputStream intputStream;
    private boolean finished;

    public ServletByteArrayIntputStream(byte[] body) {
        intputStream = new ByteArrayInputStream(body);
    }

    @Override
    public int read() throws IOException {
        final int read = intputStream.read();
        finished = read == -1;
        return read;
    }

    public ByteArrayInputStream getIntputStream() {
        return intputStream;
    }

    @Override
    public boolean isFinished() {
        return finished;
    }

    @Override
    public boolean isReady() {
        return true;
    }

    @Override
    public void setReadListener(final ReadListener listener) {
        // no-op
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/server/openejb-http/src/main/java/org/apache/openejb/server/httpd/ServletByteArrayIntputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
    * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.server.httpd;

import jakarta.servlet.ReadListener;
import jakarta.servlet.ServletInputStream;
import java.io.ByteArrayInputStream;
import java.io.IOException;

public class ServletByteArrayIntputStream extends ServletInputStream {
    private final ByteArrayInputStream intputStream;
    private boolean finished;

    public ServletByteArrayIntputStream(byte[] body) {
        intputStream = new ByteArrayInputStream(body);
    }

    @Override
    public int read() throws IOException {
        final int read = intputStream.read();
        finished = read == -1;
        return read;
    }

    public ByteArrayInputStream getIntputStream() {
        return intputStream;
    }

    @Override
    public boolean isFinished() {
        return finished;
    }

    @Override
    public boolean isReady() {
        return true;
    }

    @Override
    public void setReadListener(final ReadListener listener) {
        // no-op
    }
}
